<?php

class Codebaby_Avatar_Admin {

    const MENU_SLUG = "codebaby-avatar-settings";

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $codebaby_avatar    The ID of this plugin.
	 */
	private $codebaby_avatar;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $codebaby_avatar       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $codebaby_avatar, $version ) {

		$this->codebaby_avatar = $codebaby_avatar;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Codebaby_Avatar_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Codebaby_Avatar_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->codebaby_avatar, plugin_dir_url( __FILE__ ) . 'css/codebaby-avatar-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Codebaby_Avatar_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Codebaby_Avatar_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->codebaby_avatar, plugin_dir_url( __FILE__ ) . 'js/codebaby-avatar-admin.js', array( 'jquery' ), $this->version, false );

	}

    public function add_admin_menu()
    {
        add_menu_page(
            "Codebaby Settings",
            "Codebaby",
            "manage_options",
            self::MENU_SLUG,
            [$this, "settings_page"],
			plugin_dir_url( __FILE__ ) . '../public/images/favicon.svg'
        );
    }

    public function settings_page()
    {
        require_once plugin_dir_path(__FILE__) .
            "pages/class-codebaby-avatar-settings.php";
			Codebaby_Avatar_Settings::view(self::MENU_SLUG);
    }
}
