document.addEventListener('DOMContentLoaded', function () {
    function initializeCustomSelect(containerID, searchID, optionsID, selectedItemsID, hiddenInputID, initialSelection = []) {
        const container = document.getElementById(containerID);
        const searchInput = container.querySelector(`#${searchID}`);
        const optionsContainer = container.querySelector(`#${optionsID}`);
        const options = Array.from(optionsContainer.querySelectorAll('.option'));
        const selectedItemsContainer = container.querySelector(`#${selectedItemsID}`);
        const hiddenInput = container.querySelector(`#${hiddenInputID}`);
        let selectedItems = [];

        searchInput.addEventListener('focus', () => optionsContainer.style.display = 'block');

        document.addEventListener('click', (e) => {
            if (!container.contains(e.target)) {
                optionsContainer.style.display = 'none';
            }
        });

        searchInput.addEventListener('input', function () {
            const searchTerm = this.value.toLowerCase();
            options.forEach(option => {
                const isVisible = option.textContent.toLowerCase().includes(searchTerm);
                option.style.display = isVisible ? '' : 'none';
            });
        });

        options.forEach(option => {
            option.addEventListener('click', function () {
                const value = this.dataset.value;
                const text = this.textContent;
                if (!selectedItems.some(item => item.value === value)) {
                    selectedItems.push({ value, text });
                    updateSelectedItems();
                }
                searchInput.value = '';
                optionsContainer.style.display = 'none';
            });
        });

        function updateSelectedItems() {
            selectedItemsContainer.innerHTML = '';
            selectedItems.forEach(item => {
                const itemElement = document.createElement('div');
                itemElement.innerHTML = `<span class="selected-item">${item.text}</span>`;
                selectedItemsContainer.appendChild(itemElement);
                const itemElement2 = document.createElement('button');
                itemElement2.classList.add('remove-item');
                itemElement2.setAttribute('data-value', `${item.value}`);
                itemElement2.innerHTML = 'x';
                selectedItemsContainer.appendChild(itemElement2);
            });
            hiddenInput.value = selectedItems.map(item => item.value).join(',');

            selectedItemsContainer.querySelectorAll('.remove-item').forEach(removeButton => {
                removeButton.addEventListener('click', function () {
                    const valueToRemove = this.dataset.value;
                    selectedItems = selectedItems.filter(item => item.value !== valueToRemove);
                    updateSelectedItems();
                });
            });
        }

        updateSelectedItems();
    }

    initializeCustomSelect('selected-pages-container', 'selected-page-search', 'custom-selected-page-options', 'selected-specific-pages-items', 'selected-specific-pages');
    initializeCustomSelect('pages-container', 'page-search', 'custom-page-options', 'selected-pages-items', 'selected-pages');
    initializeCustomSelect('posts-container', 'post-search', 'custom-post-options', 'selected-posts-items', 'selected-posts');

    const siteDisplaySelect = document.getElementById('codebaby_site_display');
    const specificPagesRow = document.getElementById('selected_pages_row');
    const excludePagesRow = document.getElementById('pages-container-row');
    const excludePostsRow = document.getElementById('posts-container-row');

    function toggleSpecificPagesRow() {
        if (siteDisplaySelect.value === 'selected_pages') {
            specificPagesRow.style.display = 'table-row';
            excludePagesRow.style.display = 'none';
            excludePostsRow.style.display = 'none';
        } else {
            specificPagesRow.style.display = 'none';
            excludePagesRow.style.display = 'table-row';
            excludePostsRow.style.display = 'table-row';
        }
    }

    toggleSpecificPagesRow();

    siteDisplaySelect.addEventListener('change', toggleSpecificPagesRow);

    document.getElementById('toggle-advanced-options').addEventListener('click', function () {
        var advancedOptions = document.getElementById('advanced-options');
        if (advancedOptions.style.display === 'none') {
            advancedOptions.style.display = 'block';
        } else {
            advancedOptions.style.display = 'none';
        }
    });

    // These variables will be populated by WordPress
    const excludedPages = codebaby_admin_data.exclude_pages;
    const excludedPosts = codebaby_admin_data.exclude_posts;
    const specificPages = codebaby_admin_data.selected_pages;

    excludedPages.forEach(pageId => {
        const option = document.querySelector(`#custom-page-options .option[data-value="${pageId}"]`);
        if (option) {
            option.click();
        }
    });

    excludedPosts.forEach(postId => {
        const option = document.querySelector(`#custom-post-options .option[data-value="${postId}"]`);
        if (option) {
            option.click();
        }
    });

    specificPages.forEach(pageId => {
        const option = document.querySelector(`#custom-selected-page-options .option[data-value="${pageId}"]`);
        if (option) {
            option.click();
        }
    });
});