<?php

class Codebaby_Avatar_List
{

    public static function view($menu_slug)
    {
        global $wpdb;
        $table_name = $wpdb->prefix . "codebaby_settings";
        
        if (isset($_SERVER["REQUEST_METHOD"]) && $_SERVER["REQUEST_METHOD"] == "POST") {
            if (isset($_POST["codebaby_pages_nonce"]) && wp_verify_nonce(sanitize_text_field(wp_unslash($_POST["codebaby_pages_nonce"])), "codebaby_pages_nonce_action")) {
                if (isset($_POST["avatar_id"])) {
                    $avatar_id = sanitize_text_field(wp_unslash($_POST["avatar_id"]));
                    $new_status = isset($_POST["avatar_status"]) ? 1 : 0; // phpcs:ignore WordPress.Security.NonceVerification.Missing
                    $wpdb->query($wpdb->prepare("UPDATE {$wpdb->prefix}codebaby_settings SET status = %s WHERE id = %s", $new_status, $avatar_id)); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
                }
                if (isset($_POST["delete_avatar"])) {
                    $avatar_id = sanitize_text_field(wp_unslash($_POST["delete_avatar"]));
                    $wpdb->query($wpdb->prepare("DELETE FROM {$wpdb->prefix}codebaby_settings WHERE id = %s", $avatar_id)); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
                }
            }
        }
        $allowed_tags = [
            "script" => [
                "src" => true,
                "type" => true,
                "async" => true,
                "defer" => true,
            ],
        ];

        $editing_avatar = isset($_GET["edit_avatar"])
            ? sanitize_text_field(wp_unslash($_GET["edit_avatar"]))
            : null;
        if (
            $_SERVER["REQUEST_METHOD"] == "POST" &&
            isset($_POST["codebaby_settings_nonce"]) &&
            wp_verify_nonce(
                sanitize_text_field(wp_unslash($_POST["codebaby_settings_nonce"])),
                "codebaby_settings_nonce_action"
            )
        ) {
            $avatar_name = isset($_POST["avatar_name"]) ? sanitize_text_field(wp_unslash($_POST["avatar_name"])) : '';
            $selected_pages = isset($_POST["codebaby_selected_pages"])
                ? sanitize_text_field(wp_unslash($_POST["codebaby_selected_pages"]))
                : "";
            $selected_pages_array = !empty($selected_pages)
                ? explode(",", $selected_pages)
                : [];
            $data = [
                "avatar_name" => $avatar_name,
                "script_tag" => isset($_POST["codebaby_script_tag"])?wp_kses(
                    wp_unslash($_POST["codebaby_script_tag"]),
                    $allowed_tags
                
                ):"",
                "site_display" => sanitize_text_field(
                    wp_unslash($_POST["codebaby_site_display"] ?? '')
                ),
                "exclude_pages" => maybe_serialize(
                    array_map(
                        "intval",
                        explode(',', sanitize_text_field(wp_unslash($_POST["codebaby_exclude_pages"] ?? '')))
                    )
                ),
                "exclude_posts" => maybe_serialize(
                    isset($_POST["codebaby_exclude_posts"])
                    ? array_map("intval", $_POST["codebaby_exclude_posts"])
                    : []
                ),
                "selected_pages" => maybe_serialize(
                    array_map("intval", $selected_pages_array)
                ),
                "device_display" => sanitize_text_field(
                    wp_unslash($_POST["codebaby_device_display"] ?? '')
                ),
                "status" => sanitize_text_field(
                    wp_unslash($_POST["codebaby_status"] ?? '')
                ),
                "start_phrase" => sanitize_text_field(
                    wp_unslash($_POST["codebaby_start_phrase"] ?? '')
                ),
                "start_data" => sanitize_text_field(
                    wp_unslash( $_POST["codebaby_start_data"] ?? '')
                ),
            ];
            if ($editing_avatar) {
                $existing_row = $wpdb->get_row($wpdb->prepare("SELECT * FROM {$wpdb->prefix}codebaby_settings WHERE id = %s", $editing_avatar)); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
                if ($existing_row) {
                    $wpdb->update($table_name, $data, ["id" => $editing_avatar]); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
                }
            } else {
                $wpdb->insert($table_name, $data); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
            }

        }
        $avatars = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}codebaby_settings"); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
        foreach ($avatars as $avatar) {
            $avatar->exclude_pages = maybe_unserialize($avatar->exclude_pages);
            $avatar->exclude_posts = maybe_unserialize($avatar->exclude_posts);
            $avatar->selected_pages = maybe_unserialize(
                $avatar->selected_pages
            );
        }
        // Step 1: Flatten the specific_pages arrays and track IDs
        $all_pages_with_ids = [];
        $all_pages = get_posts(['post_type' => 'page', 'posts_per_page' => -1, 'fields' => 'ids']);
        $all_posts = get_posts(['post_type' => 'post', 'posts_per_page' => -1, 'fields' => 'ids']);

        // Combine all pages and posts into a single array (since you may want to treat them the same way)
        $all_pages_and_posts = array_merge($all_pages, $all_posts);
        foreach ($avatars as $item) {
            if ($item->status) {
                if ($item->site_display == 'site_wide') {
                    $included_pages = array_diff($all_pages_and_posts, $item->exclude_pages ?? [], $item->exclude_posts ?? []);

                    foreach ($included_pages as $page) {
                        if (!isset($all_pages_with_ids[$page])) {
                            $all_pages_with_ids[$page] = [];
                        }
                        $all_pages_with_ids[$page][] = $item->id;
                    }
                } elseif ($item->site_display == 'selected_pages' && isset($item->selected_pages)) {
                    foreach ($item->selected_pages as $page) {
                        if (!isset($all_pages_with_ids[$page])) {
                            $all_pages_with_ids[$page] = [];
                        }
                        $all_pages_with_ids[$page][] = $item->id;
                    }
                }
            }
        }

        // Step 2: Identify duplicates and the corresponding IDs
        $duplicate_info = [];
        foreach ($all_pages_with_ids as $page => $ids) {
            if (count($ids) > 1) {
                $duplicate_info[$page] = $ids;
            }
        }
        $admin_page_url = menu_page_url($menu_slug, false);
        $admin_page_url .="&edit_avatar=new";
        ?>
        <div class="wrap">
            <div>
                <img src="<?php echo esc_url(plugins_url('/public/images/codebaby.svg', dirname(__FILE__, 2))); ?>"
                    width="30%" />
                <div class="wrap">
                    <a href="<?php echo esc_url(wp_nonce_url($admin_page_url, 'edit-avatar', 'edit-avatar_nonce' )); ?>"
                        class="button button-secondary"><?php esc_attr_e("Add Avatar", "codebaby-avatar"); ?></a>
                    <a href="https://portal.codebaby.com/admin/avatars" class="button button-secondary"
                        target="_blank"><?php esc_attr_e("Create Avatar on Codebaby Portal", "codebaby-avatar"); ?></a>
                </div>
            </div>
            <?php
            // Display duplicates
            if (!empty($duplicate_info)) {
                foreach ($duplicate_info as $page => $ids) {
                    echo "<div class=\"error notice\"><p>Error: The Page \"" . esc_html(get_the_title($page)) . "\" has multiple avatars. [ " . esc_html(implode('", "', array_map(fn($id) => current(array_filter($avatars, fn($obj) => $obj->id === $id))->avatar_name, $ids))) . " ], this may result in unexpected behaviour.</p></div>";
                }
            } ?>
            <form method="post" action="">
                <?php wp_nonce_field(
                    "codebaby_pages_nonce_action",
                    "codebaby_pages_nonce"
                ); ?>

                <div class="table-container">
                    <table class="cb-table">
                        <thead>
                            <tr>
                                <th><?php esc_attr_e(
                                    "Avatar Name",
                                    "codebaby-avatar"
                                ); ?></th>
                                <th><?php esc_attr_e(
                                    "Status",
                                    "codebaby-avatar"
                                ); ?></th>
                                <th><?php esc_attr_e(
                                    "Display On",
                                    "codebaby-avatar"
                                ); ?></th>
                                <th><?php esc_attr_e(
                                    "Devices",
                                    "codebaby-avatar"
                                ); ?></th>
                                <th><?php esc_attr_e(
                                    "Shortcode",
                                    "codebaby-avatar"
                                ); ?></th>
                                <th><?php esc_attr_e(
                                    "Actions",
                                    "codebaby-avatar"
                                ); ?></th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($avatars as $avatar): ?>
                                <?php
                                    $edit_url = admin_url("admin.php?page=" . esc_attr($menu_slug) . "&edit_avatar=" . esc_attr($avatar->id));
                                    $edit_avatar_url = wp_nonce_url( $edit_url, 'edit-avatar', 'edit-avatar_nonce' );
                                     ?>
                                <tr>
                                    <td><?php echo esc_html(
                                        $avatar->avatar_name
                                    ); ?></td>
                                    <td>
                                        <form method="post" action="">
                                            <?php wp_nonce_field(
                                                "codebaby_pages_nonce_action",
                                                "codebaby_pages_nonce"
                                            ); ?>
                                            <input type="hidden" name="avatar_id" value="<?php echo esc_html(
                                                $avatar->id
                                            ); ?>">
                                            <label class="switch">
                                                <input type="checkbox" name="avatar_status" value="1" <?php checked(
                                                    $avatar->status,
                                                    1
                                                ); ?> onchange="this.form.submit();" />
                                                <span class="slider"></span>
                                            </label>
                                        </form>
                                    </td>
                                    <td><?php echo esc_html(
                                        $avatar->site_display
                                    ); ?></td>
                                    <td><?php echo esc_html(
                                        $avatar->device_display
                                    ); ?></td>
                                    <td>[codebaby <?php echo esc_attr(
                                        Codebaby_Avatar_List::extract_id_from_script_tag(
                                            $avatar->script_tag
                                        ) .
                                        esc_attr(
                                            Codebaby_Avatar_List::extract_start_phrase_from_script_tag(
                                                $avatar->script_tag
                                            )
                                        ) .
                                        esc_attr(
                                            Codebaby_Avatar_List::extract_start_data_from_script_tag(
                                                $avatar->script_tag
                                            )
                                        )
                                    ); ?>]</td>
                                    <td class="action-buttons">
                                        <a href="<?php echo esc_url($edit_avatar_url); ?>"
                                            class="button"><?php esc_html_e("Edit", "codebaby-avatar"); ?></a>
                                        <button type="submit" name="delete_avatar" value="<?php echo esc_attr(
                                            $avatar->id
                                        ); ?>" class="button"><?php esc_attr_e(
                                             "Delete",
                                             "codebaby-avatar"
                                         ); ?></button>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                <?php
    }
    public static function extract_id_from_script_tag($script_tag)
    {
        preg_match('/id=([^&|^"]*)/', $script_tag, $matches);
        return isset($matches[1]) ? 'id="' . urldecode($matches[1]) . '"' : "";
    }
    public static function extract_start_phrase_from_script_tag($script_tag)
    {
        preg_match('/startPhrase=([^&|^""]*)/', $script_tag, $matches);
        return isset($matches[1]) ? ' start_phrase="' . urldecode($matches[1]) . '"' : "";
    }
    public static function extract_start_data_from_script_tag($script_tag)
    {
        preg_match('/startData=([^&|^""]*)/', $script_tag, $matches);
        return isset($matches[1]) ? ' start_data="' . urldecode($matches[1]) . '"' : "";
    }
}