<?php

class Codebaby_Avatar_View
{

    public static function view()
    {
        global $wpdb;
        $table_name = $wpdb->prefix . "codebaby_settings";
        $allowed_tags = [
            "script" => [
                "src" => true,
                "type" => true,
                "async" => true,
                "defer" => true,
            ],
        ];

        $actionUrl = admin_url("admin.php?page=codebaby-avatar-settings");
        $editing_avatar = null;
        $avatar_data = null;
        if (isset($_GET["edit-avatar_nonce"]) && wp_verify_nonce(sanitize_text_field(wp_unslash($_GET["edit-avatar_nonce"])), "edit-avatar")) {
            $editing_avatar = isset($_GET["edit_avatar"])
                ? sanitize_text_field(wp_unslash($_GET["edit_avatar"]))
                : null;

            if ($editing_avatar && $editing_avatar == 'new') {
                $editing_avatar = null;
            }
            if ($editing_avatar) {
                $actionUrl .= "&edit_avatar=" . $editing_avatar;
                $avatar_data = $wpdb->get_row($wpdb->prepare("SELECT * FROM {$wpdb->prefix}codebaby_settings WHERE id = %s", $editing_avatar)); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
            }
        }

        $avatar_name = $editing_avatar ? $avatar_data->avatar_name : "";
        $script_tag = $editing_avatar ? $avatar_data->script_tag : "";
        $site_display = $editing_avatar ? $avatar_data->site_display : "";
        $device_display = $editing_avatar ? $avatar_data->device_display : "";
        $status = $editing_avatar ? $avatar_data->status : "";
        $start_phrase = $editing_avatar ? $avatar_data->start_phrase : "";
        $start_data = $editing_avatar ? $avatar_data->start_data : "";
        $selected_pages = $editing_avatar
            ? maybe_unserialize($avatar_data->selected_pages)
            : [];
        $exclude_pages = $editing_avatar
            ? maybe_unserialize($avatar_data->exclude_pages)
            : [];
        $exclude_posts = $editing_avatar
            ? maybe_unserialize($avatar_data->exclude_posts)
            : [];
        $edit_avatar_url = wp_nonce_url($actionUrl, 'edit-avatar', 'edit-avatar_nonce');

        wp_enqueue_script('codebaby-avatar-view', plugin_dir_url(__FILE__) . '../js/codebaby-avatar-view.js', array('jquery'), '1.0.0', true);

        $script_data = array(
            'exclude_pages' => $exclude_pages,
            'exclude_posts' => $exclude_posts,
            'selected_pages' => $selected_pages,
        );
        wp_localize_script('codebaby-avatar-view', 'codebaby_admin_data', $script_data);

        ?>

        <div class="wrap">
            <h1><?php esc_attr_e("Codebaby Settings", "codebaby-avatar"); ?></h1>
            <form method="post" action="<?php echo esc_url($edit_avatar_url); ?>">
                <?php wp_nonce_field(
                    "codebaby_settings_nonce_action",
                    "codebaby_settings_nonce"
                ); ?>

                <table class="form-table">
                    <tr valign="top">
                        <th scope="row"><?php esc_attr_e(
                            "Avatar Name",
                            "codebaby-avatar"
                        ); ?></th>
                        <td>
                            <input type="text" name="avatar_name" value="<?php echo esc_attr(
                                $avatar_name
                            ); ?>" required />
                            <p class="description"><?php esc_attr_e(
                                "Enter a new avatar name and save settings to add it.",
                                "codebaby-avatar"
                            ); ?></p>
                        </td>
                    </tr>
                    <tr valign="top">
                        <th scope="row"><?php esc_attr_e(
                            "Script Tag",
                            "codebaby-avatar"
                        ); ?></th>
                        <td>
                            <textarea name="codebaby_script_tag" required
                                style="width: 100%; max-width: 400px; height: 100px;"><?php echo esc_attr($script_tag); ?></textarea>
                        </td>
                    </tr>
                    <tr valign="top">
                        <th scope="row"><?php esc_attr_e(
                            "Site Display",
                            "codebaby-avatar"
                        ); ?></th>
                        <td>
                            <select name="codebaby_site_display" id="codebaby_site_display" required>
                                <option value="site_wide" <?php selected(
                                    $site_display,
                                    "site_wide"
                                ); ?>><?php esc_attr_e("Site Wide", "codebaby-avatar"); ?></option>
                                <option value="selected_pages" <?php selected(
                                    $site_display,
                                    "selected_pages"
                                ); ?>><?php esc_attr_e("Specific Posts/Pages", "codebaby-avatar"); ?></option>
                            </select>
                        </td>
                    </tr>
                    <tr valign="top" id="selected_pages_row" style="display: none;">
                        <th scope="row"><?php esc_attr_e(
                            "Selected Posts/Pages",
                            "codebaby-avatar"
                        ); ?></th>
                        <td>
                            <div class="custom-select-container" id="selected-pages-container">
                                <div class="selected-items" id="selected-specific-pages-items"></div>
                                <input type="text" id="selected-page-search" placeholder="Search and select posts/pages">

                                <div id="custom-selected-page-options" class="custom-options">
                                    <?php

                                    $pages = get_pages();
                                    foreach ($pages as $page) {
                                        echo '<div class="option" data-value="' .
                                            esc_attr($page->ID) .
                                            '">' .
                                            esc_html($page->post_title) .
                                            "</div>";
                                    }
                                    $posts = get_posts([
                                        "posts_per_page" => -1,
                                    ]);
                                    foreach ($posts as $post) {
                                        echo '<div class="option" data-value="' .
                                            esc_attr($post->ID) .
                                            '">' .
                                            esc_html($post->post_title) .
                                            "</div>";
                                    }
                                    ?>
                                </div>
                                <input type="hidden" name="codebaby_selected_pages" id="selected-specific-pages" value="<?php echo esc_attr(
                                    $selected_pages
                                ); ?>">
                            </div>
                            <p class="description"><?php esc_attr_e(
                                "Select pages/posts where the avatar should appear.",
                                "codebaby-avatar"
                            ); ?></p>
                        </td>
                    </tr>
                    <tr valign="top" id="pages-container-row">
                        <th scope="row"><?php esc_attr_e(
                            "Exclude Pages",
                            "codebaby-avatar"
                        ); ?></th>
                        <td>
                            <div class="custom-select-container" id="pages-container">
                                <div class="selected-items" id="selected-pages-items"></div>
                                <input type="text" id="page-search" placeholder="<?php esc_attr_e(
                                    "Search and select pages",
                                    "codebaby-avatar"
                                ); ?>">
                                <div id="custom-page-options" class="custom-options">
                                    <?php
                                    $pages = get_pages();
                                    foreach ($pages as $page) {
                                        echo '<div class="option" data-value="' .
                                            esc_attr($page->ID) .
                                            '">' .
                                            esc_html($page->post_title) .
                                            "</div>";
                                    }
                                    ?>
                                </div>
                                <input type="hidden" name="codebaby_exclude_pages" id="selected-pages"
                                    value="<?php echo esc_attr(implode(',', $exclude_pages)); ?>">
                            </div>
                            <p class="description"><?php esc_attr_e(
                                "Select pages where the avatar should not appear.",
                                "codebaby-avatar"
                            ); ?></p>
                        </td>
                    </tr>
                    <tr valign="top" id="posts-container-row">
                        <th scope="row"><?php esc_attr_e(
                            "Exclude Posts",
                            "codebaby-avatar"
                        ); ?></th>
                        <td>
                            <div class="custom-select-container" id="posts-container">
                                <div class="selected-items" id="selected-posts-items"></div>
                                <input type="text" id="post-search" placeholder="<?php esc_attr_e(
                                    "Search and select posts",
                                    "codebaby-avatar"
                                ); ?>">
                                <div id="custom-post-options" class="custom-options">
                                    <?php
                                    $posts = get_posts([
                                        "posts_per_page" => -1,
                                    ]);
                                    foreach ($posts as $post) {
                                        echo '<div class="option" data-value="' .
                                            esc_attr($post->ID) .
                                            '">' .
                                            esc_html($post->post_title) .
                                            "</div>";
                                    }
                                    ?>
                                </div>
                                <input type="hidden" name="codebaby_exclude_posts[]" id="selected-posts" value="<?php echo esc_attr(
                                    $exclude_posts
                                ); ?>">
                            </div>
                            <p class="description"><?php esc_attr_e(
                                "Select posts where the avatar should not appear.",
                                "codebaby-avatar"
                            ); ?></p>
                        </td>
                    </tr>
                    <tr valign="top">
                        <th scope="row"><?php esc_attr_e(
                            "Device Display",
                            "codebaby-avatar"
                        ); ?></th>
                        <td>
                            <select name="codebaby_device_display">
                                <option value="all_devices" <?php selected(
                                    $device_display,
                                    "all_devices"
                                ); ?>>
                                    <?php esc_attr_e("All Devices", "codebaby-avatar"); ?>
                                </option>
                                <option value="mobile_only" <?php selected(
                                    $device_display,
                                    "mobile_only"
                                ); ?>><?php esc_attr_e("Mobile Only", "codebaby-avatar"); ?></option>
                                <option value="desktop_only" <?php selected(
                                    $device_display,
                                    "desktop_only"
                                ); ?>><?php esc_attr_e("Desktop Only", "codebaby-avatar"); ?></option>
                            </select>
                        </td>
                    </tr>
                    <tr valign="top">
                        <th scope="row"><?php esc_attr_e(
                            "Status",
                            "codebaby-avatar"
                        ); ?></th>
                        <td>
                            <select name="codebaby_status">
                                <option value="1" <?php selected(
                                    $status,
                                    "1"
                                ); ?>><?php esc_attr_e("Active", "codebaby-avatar"); ?></option>
                                <option value="0" <?php selected(
                                    $status,
                                    "0"
                                ); ?>><?php esc_attr_e("Inactive", "codebaby-avatar"); ?></option>
                            </select>
                        </td>
                    </tr>
                </table>

                <div>
                    <button class="button button-primary" type="button" id="toggle-advanced-options"><?php esc_attr_e(
                        "Advanced Options",
                        "codebaby-avatar"
                    ); ?></button>
                </div>

                <div id="advanced-options" style="display: none;">
                    <table class="form-table">
                        <tr valign="top">
                            <th scope="row"><?php esc_attr_e(
                                "Start Phrase",
                                "codebaby-avatar"
                            ); ?></th>
                            <td><input type="text" name="codebaby_start_phrase" value="<?php echo esc_attr(
                                $start_phrase
                            ); ?>" /></td>
                        </tr>
                        <tr valign="top">
                            <th scope="row"><?php esc_attr_e(
                                "Start Data",
                                "codebaby-avatar"
                            ); ?></th>
                            <td><input type="text" name="codebaby_start_data" value="<?php echo esc_attr(
                                $start_data
                            ); ?>" /></td>
                        </tr>
                    </table>
                </div>

                <?php submit_button(__("Save Settings", "codebaby-avatar")); ?>
            </form>
        </div>

        <?php
    }

}