<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Codebaby_Avatar
 * @subpackage Codebaby_Avatar/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Codebaby_Avatar
 * @subpackage Codebaby_Avatar/public
 * @author     Your Name <email@example.com>
 */
class Codebaby_Avatar_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $codebaby_avatar    The ID of this plugin.
	 */
	private $codebaby_avatar;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $codebaby_avatar       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $codebaby_avatar, $version ) {

		$this->codebaby_avatar = $codebaby_avatar;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Codebaby_Avatar_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Codebaby_Avatar_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

	}
	
    public function include_avatar_in_header()
    {
        if (is_admin()) {
            return;
        }
        global $post, $wpdb;
        $table_name = $wpdb->prefix . "codebaby_settings";
        $avatars = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}codebaby_settings"); // phpcs:ignore WordPress.DB.DirectDatabaseQuery
        if (!$avatars) {
            return;
        }
        ob_start();
        foreach ($avatars as $avatar) {
            if ($avatar->status != 1) {
                continue;
            }
            $site_display = $avatar->site_display;
            $exclude_pages = maybe_unserialize($avatar->exclude_pages);
            $exclude_posts = maybe_unserialize($avatar->exclude_posts);
            $device_display = $avatar->device_display;
            $should_display = false;
    
            if (is_singular()) {
                $current_id = get_the_ID();
                
                if (in_array($current_id, (array)$exclude_pages) || in_array($current_id, (array)$exclude_posts)) {
                    continue;
                }
    
                if ($site_display === "site_wide" || 
                    ($site_display === "selected_pages" && !empty($avatar->selected_pages) && in_array($current_id, maybe_unserialize($avatar->selected_pages)))) {
                    $should_display = true;
                }
            } else {
                $should_display = ($site_display === "site_wide");
            }
    
            if ($should_display) {
                switch ($device_display) {
                    case "all_devices":
                        $should_display = true;
                        break;
                    case "mobile_only":
                        $should_display = wp_is_mobile();
                        break;
                    case "desktop_only":
                        $should_display = !wp_is_mobile();
                        break;
                }
            }
    
            if ($should_display) {
                $script_tag = $avatar->script_tag;
                if (!empty($script_tag)) {
					preg_match('/ src="([^"]*)/', $script_tag, $matches);
					$url = isset($matches[1]) ? $matches[1] : "";
					$paramsToUpdate = ['startData' => $avatar->start_data,
						'startPhrase' => $avatar->start_phrase ];
					$newUrl = $this->updateQueryParams($url, $paramsToUpdate);
					wp_enqueue_script( 'codebaby', $newUrl, array(), $this->version, true );
					?>
					<?php
                }
            }
        }
        ob_end_flush();
    }
	function updateQueryParams($url, $paramsToUpdate) {
		// Decode the URL to handle any unescaped characters
		$decodedUrl = urldecode($url);
		// Parse the URL into its components
		$parsedUrl = wp_parse_url($decodedUrl);

		// Parse the query string into an associative array
		$queryParams = [];
		if (isset($parsedUrl['query'])) {
			parse_str(html_entity_decode($parsedUrl['query']), $queryParams);
		}

		// Update the query parameters with the new values, only if the value is not null
		foreach ($paramsToUpdate as $key => $value) {
			if ($value !== null && $value != "") {
				$queryParams[$key] = $value;
			}
		}
	
		// Build the query string from the updated parameters
		$newQueryString = http_build_query($queryParams, '', '&');
	
		// Rebuild the URL with the new query string
		$newUrl = $parsedUrl['scheme'] . '://' . $parsedUrl['host'] . $parsedUrl['path'];
		if ($newQueryString) {
			$newUrl .= '?' . $newQueryString;
		}
	
		// If the URL has a fragment (hash), append it
		if (isset($parsedUrl['fragment'])) {
			$newUrl .= '#' . $parsedUrl['fragment'];
		}
	
		return $newUrl;
	}
}
