const { registerBlockType } = wp.blocks;
const { TextControl, Dropdown, Button } = wp.components;
const { createElement, useState } = wp.element;

const triggerOptions = [
  {
    label: "Toggle microphone from on/off",
    value: "na-microphoneToggle.vidbaby",
  },
  { label: "Pause player", value: "na-pause.vidbaby" },
  { label: "Resume playing after paused", value: "na-play.vidbaby" },
  { label: "Mute avatar", value: "na-mute.vidbaby" },
  { label: "Unmute avatar", value: "na-unmute.vidbaby" },
  { label: "Send question to avatar", value: "na-ask.vidbaby" },
  {
    label: "Restart conversation without reloading",
    value: "na-resetConversation.vidbaby",
  },
];

var avatarId = codebabySettings.avatarId;

registerBlockType("codebaby/block-button", {
  title: "Code Baby Button",
  icon: "button",
  category: "widgets",
  attributes: {
    action: { type: "string", default: "na-ask.vidbaby" },
    question: { type: "string", default: "Hello, how are you?" },
  },
  edit: function (props) {
    const { attributes, setAttributes } = props;
    const { action, question } = attributes;

    const [isOpen, setIsOpen] = useState(false);

    function onChangeAction(newAction) {
      setAttributes({ action: newAction });
      setIsOpen(false);
    }

    function onChangeQuestion(newQuestion) {
      setAttributes({ question: newQuestion });
      setIsOpen(false);
    }

    return createElement(
      "div",
      { className: "codebaby-button-editor" },
      createElement(Dropdown, {
        contentClassName: "codebaby-dropdown",
        position: "bottom right",
        renderToggle: ({ isOpen, onToggle }) =>
          createElement(
            Button,
            {
              isPrimary: true,
              onClick: onToggle,
            },
            action
              ? triggerOptions.find((option) => option.value === action).label
              : "Select Action"
          ),
        renderContent: () =>
          createElement(
            "ul",
            {
              className: "codebaby-dropdown-menu",
              style: {
                minWidth: "300px",
                cursor: "pointer",
                marginBottom: "10px",
              },
            },
            triggerOptions.map((option) =>
              createElement(
                "li",
                {
                  key: option.value,
                  onClick: () => {
                    onChangeAction(option.value);
                    setIsOpen(false);
                  },
                  style: {
                    borderRadius: "10px",
                    padding: "8px 12px",
                    cursor: "pointer",
                    transition: "background-color 0.3s ease",
                    border: "2px solid transparent",
                  },
                  onMouseEnter: (event) => {
                    event.target.style.backgroundColor = "#f0f0f0";
                    event.target.style.border = "2px solid #ccc";
                  },
                  onMouseLeave: (event) => {
                    event.target.style.backgroundColor = "transparent";
                    event.target.style.border = "2px solid transparent";
                  },
                },
                option.label
              )
            )
          ),
      }),
      action === "na-ask.vidbaby" &&
        createElement(TextControl, {
          label: "Question",
          value: question,
          onChange: onChangeQuestion,
          placeholder: "Enter your question",
          style: { marginTop: "5px" },
        })
    );
  },
  save: function (props) {
    const { attributes } = props;
    const { action, question } = attributes;

    return createElement(
      "button",
      {
        className: "codebaby-button",
        style: {
          maxWidth: "300px",
          minHeight: "40px",
          cursor: "pointer",
          borderRadius: "10px",
          padding: "10px 15px",
          cursor: "pointer",
          border: "2px solid transparent",
          backgroundColor: "#0073aa",
          color: "#ffffff",
        },
        "data-action": action,
        "data-question": action === "na-ask.vidbaby" ? question : "",
      },
      action
        ? triggerOptions.find((option) => option.value === action).label
        : "Code Baby Button"
    );
  }  
});

registerBlockType("codebaby/widget", {
  title: "Code Baby Avatar",
  icon: "hammer",
  category: "widgets",
  attributes: {
    avatarId: { type: "string", default: codebabySettings.avatarId },
  },
  edit: function (props) {
    const { attributes, setAttributes } = props;
    const { avatarId } = attributes;

    return createElement(
      "div",
      { className: "custom-block-editor" },
      createElement("p", null, "Codebaby-Avatar")
    );
  },
  save: function (props) {
    return null;
  },
});
